/* nocomment.l -- strip all 'C[++]' comments from input */
%option 8bit warn nodefault
%option noyywrap yylineno
%option noinput nounput

%x CMNT

%%

"/*"               { BEGIN(CMNT); }
<CMNT>"*/"         { BEGIN(INITIAL); }
<CMNT>([^*]|\n)|.
<CMNT><<EOF>>      { fprintf(stderr, "oops, comment open in line %d\n",
                               yylineno);
                     return 1;
                   }
"//".*\n

.|\n               { fputc(*yytext, yyout); }

%%

#define FNBUFSZ  1024

int main(int argc, char *argv[]) {
  if (2 != argc) {
    fprintf(stderr, "usage:  %s <myscene>\n", argv[0]);
    return 1;
  }

  char outname[FNBUFSZ] = {'\0'};
  int const n = snprintf(outname, FNBUFSZ, "nc_%s", argv[1]);
  if (FNBUFSZ <= n) {
    fprintf(stderr, "oops, output file name too long.\n");
    return 1;
  }
  else if ((yyout = fopen(outname, "r"))) {
    fprintf(stderr, "oops, output file already exists.\n");
    return 1;
  }
  else if (!(yyin = fopen(argv[1], "rb"))) {
    int const e = errno;
    fprintf(stderr, "oops, error opening file: %s.\n", strerror(e));
    return 1;
  }
  else if (!(yyout = fopen(outname, "wb"))) {
    int const e = errno;
    fprintf(stderr, "oops, error creating file: %s.\n", strerror(e));
    return 1;
  }

  yylex();

  (void)fclose(yyin);
  if (fclose(yyout)) {
    int const e = errno;
    fprintf(stderr, "oops, error closing file: %s.\n", strerror(e));
    return 1;
  }

  return 0;
}

